/*
 * Copyright 2011 E-Government Innovation Center (EGIZ)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package at.gv.zustellung.zusemsg.config;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import at.gv.util.ssl.JaxWsSSLConfiguration;
import at.gv.util.ssl.JaxWsSSLConfigurationPropertiesImpl;

public class PropertiesZuseMsgConfiguration implements ZuseMsgConfiguration {

	Logger log = LoggerFactory.getLogger(PropertiesZuseMsgConfiguration.class);
	
	private Properties props;
	private String configDir = null;
	private Zuse2AppConfiguration zuse2appConfig = null;
	private JaxWsSSLConfiguration sslConfiguration = null;
	
	public PropertiesZuseMsgConfiguration(String propertiesFileName) throws IOException {
		if (propertiesFileName == null) {
			throw new NullPointerException("Parameter propertiesFile must not be null.");
		}
		File propertiesFile = new File(propertiesFileName);
		FileInputStream fis = new FileInputStream(propertiesFile);
		this.configDir = propertiesFile.getParentFile().getAbsolutePath();
		log.trace("ZuseMsg Configuration directory: " + this.configDir);
		this.props = new Properties();
		props.load(fis);
		
		initialize();
	}
	
	public PropertiesZuseMsgConfiguration(Properties props, String configDir) {
		if (props == null) {
			throw new NullPointerException("Parameter props must not be null.");
		}
		if (configDir == null) {
			throw new NullPointerException("Argument 'configDir' must not be null.");
		}
		this.configDir = configDir;
		this.props = props;
		
		initialize();
	}
	
	private void initialize() {
		 sslConfiguration = new JaxWsSSLConfigurationPropertiesImpl(this.props, this.configDir, "zusemsg"); 
	}
	
	public String getZusContainerName() {
	  return props.getProperty("zusemsg.zus.container.name");
  }

	public String getZusEntryName() {
		return props.getProperty("zusemsg.zus.container.entry.name");
  }


	@Override
  public Zuse2AppConfiguration getZuse2AppConfiguration() throws IOException {
	  if (zuse2appConfig == null) {
	  	zuse2appConfig = new PropertiesZuse2AppConfiguration(this.props, this.configDir);
	  }
	  return zuse2appConfig;
  }

	@Override
  public JaxWsSSLConfiguration getSSLConfiguration() {
	  return sslConfiguration;
  }

}
